@@ -39,7 +39,7 @@ import hypothesis.internal.reflection as reflection
 from hypothesis import settings as Settings
 from hypothesis.errors import UnsatisfiedAssumption
 from hypothesis.strategies import just, sets, text, lists, floats, \
-    tuples, booleans, integers, sampled_from
+    one_of, tuples, booleans, integers, sampled_from
 from hypothesis.internal.compat import hrange
 from hypothesis.internal.conjecture.engine import \
     TestRunner as ConTestRunner
@@ -416,3 +416,133 @@ test_integers_are_sometimes_zero = define_test(
 test_integers_are_often_small = define_test(
     integers(), 0.2, lambda x: abs(x) <= 100
 )
+
+
+# This series of tests checks that the one_of() strategy flattens branches
+# correctly.  We assert that the probability of any branch is >= 0.1,
+# approximately (1/8 = 0.125), regardless of how heavily nested it is in the
+# strategy.
+
+# This first strategy chooses an integer between 0 and 7 (inclusive).
+one_of_nested_strategy = one_of(
+    just(0),
+    one_of(
+        just(1),
+        just(2),
+        one_of(
+            just(3),
+            just(4),
+            one_of(
+                just(5),
+                just(6),
+                just(7)
+            )
+        )
+    )
+)
+
+for i in range(8):
+    exec('''test_one_of_flattens_branches_%d = define_test(
+        one_of_nested_strategy, 0.1, lambda x: x == %d
+    )''' % (i, i))
+
+
+xor_nested_strategy = (
+    just(0) | (
+        just(1) | just(2) | (
+            just(3) | just(4) | (
+                just(5) | just(6) | just(7)
+            )
+        )
+    )
+)
+
+for i in range(8):
+    exec('''test_xor_flattens_branches_%d = define_test(
+        xor_nested_strategy, 0.1, lambda x: x == %d
+    )''' % (i, i))
+
+
+# This strategy tests interactions with `map()`.  They generate integers
+# from the set {1, 4, 6, 16, 20, 24, 28, 32}.
+double = lambda x: x * 2
+one_of_nested_strategy_with_map = one_of(
+    just(1),
+    one_of(
+        (just(2) | just(3)).map(double),
+        one_of(
+            (just(4) | just(5)).map(double),
+            one_of(
+                (just(6) | just(7) | just(8)).map(double)
+            )
+        ).map(double)
+    )
+)
+
+for i in (1, 4, 6, 16, 20, 24, 28, 32):
+    exec('''test_one_of_flattens_map_branches_%d = define_test(
+        one_of_nested_strategy_with_map, 0.1, lambda x: x == %d
+    )''' % (i, i))
+
+
+# This strategy tests interactions with `flatmap()`.  It generates lists
+# of length 0-7 (inclusive) in which every element is `None`.
+one_of_nested_strategy_with_flatmap = just(None).flatmap(
+    lambda x: one_of(
+        just([x] * 0), just([x] * 1), one_of(
+            just([x] * 2), just([x] * 3), one_of(
+                just([x] * 4), just([x] * 5), one_of(
+                    just([x] * 6), just([x] * 7),
+                )
+            )
+        )
+    )
+)
+
+for i in range(8):
+    exec('''test_one_of_flattens_flatmap_branches_%d = define_test(
+        one_of_nested_strategy_with_flatmap, 0.1, lambda x: len(x) == %d
+    )''' % (i, i))
+
+
+xor_nested_strategy_with_flatmap = just(None).flatmap(
+    lambda x: (
+        just([x] * 0) | just([x] * 1) | (
+            just([x] * 2) | just([x] * 3) | (
+                just([x] * 4) | just([x] * 5) | (
+                    just([x] * 6) | just([x] * 7)
+                )
+            )
+        )
+    )
+)
+
+for i in range(8):
+    exec('''test_xor_flattens_flatmap_branches_%d = define_test(
+        xor_nested_strategy_with_flatmap, 0.1, lambda x: len(x) == %d
+    )''' % (i, i))
+
+
+# This strategy tests interactions with `filter()`.  It generates the even
+# integers {0, 2, 4, 6} in equal measures.
+one_of_nested_strategy_with_filter = one_of(
+    just(0),
+    just(1),
+    one_of(
+        just(2),
+        just(3),
+        one_of(
+            just(4),
+            just(5),
+            one_of(
+                just(6),
+                just(7),
+            )
+        )
+    )
+).filter(lambda x: x % 2 == 0)
+
+for i in range(4):
+    exec('''test_one_of_flattens_filter_branches_%d = define_test(
+        one_of_nested_strategy_with_filter, 0.2, lambda x: x == 2 * %d
+    )''' % (i, i))
